|
|
|
| Description |
| Interface to the Mollom API
|
|
| Synopsis |
|
|
|
| Documentation |
|
|
| request a list of Mollom servers that can handle a site's calls.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
| :: String | type of statistics demanded
total_days Number of days Mollom has been used.
total_accepted Total accepted posts.
total_rejected Total rejected spam posts.
yesterday_accepted Number of posts accepted yesterday.
yesterday_rejected Number of spam posts blocked yesterday.
today_accepted Number of posts accepted today.
today_rejected Number of spam posts rejected today.
| | -> MollomMonad Int | Value of requested statistic
| | retrieves usage statistics from Mollom.
|
|
|
|
|
|
|
|
|
|
|
|
|
| :: String | text to blacklist
| | -> MollomMonad Bool | always returns True
| | remove text from your site's custom text blacklist.
|
|
|
|
| :: MollomMonad [[(String, MollomValue)]] | List of the current blacklisted URLs for the website corresponding to the public and private keypair
| | return the contents of your site's custom text blacklist.
|
|
|
|
| :: String | URL to be added to custom URL blacklist for the website identified by the public and private keypair
| | -> MollomMonad Bool | always returns True
| | add a URL to your site's custom URL blacklist.
|
|
|
|
| :: String | URL to be removed from the custom URL blacklist for the website identified by the public and private keypair
| | -> MollomMonad Bool | always returns True
| | remove a URL from your site's custom URL blacklist.
|
|
|
|
| :: MollomMonad [[(String, MollomValue)]] | List of the current blacklisted URLs for the website corresponding to the public and private keypair
| | return the contents of your site's custom URL blacklist.
|
|
|
| data MollomConfiguration | Source |
|
| Constructors | | Instances | |
|
|
|
| Constructors | | Instances | |
|
|
| Produced by Haddock version 2.7.2 |